@@ -23,6 +23,7 @@
 #include <QDebug>
 
 #include "keepassxmlstreamreader.h"
+#include "keepassxmlstreamwriter.h"
 
 EntryListModel::EntryListModel(QObject *parent) :
     QAbstractListModel(parent)
@@ -72,9 +73,11 @@ void EntryListModel::addFromByteArray(const QByteArray &data){
 
     qDebug("Beginning to insert data into model.");
     beginResetModel();
+    QRegExp xhtmlLineFeed("<br/>|<br />");
     while(line != 0 && line.length() > 0){
         QStringList list = line.split(CSV_SEP, QString::KeepEmptyParts);
-        m_entries << Entry(list.at(0), list.at(1), list.at(2), list.at(3), list.at(4));
+        QString notes = list.at(4);
+        m_entries << Entry(list.at(0), list.at(1), list.at(2), list.at(3), notes.replace(xhtmlLineFeed, "\n"));
         line = in.readLine();
     }
     qSort(m_entries.begin(), m_entries.end(), entryCompare);
@@ -135,7 +138,7 @@ QByteArray EntryListModel::toByteArray(){
 
     for(int i = 0; i < m_entries.size(); i++){
         Entry e = m_entries.at(i);
-        out << e.name() << CSV_SEP << e.category() << CSV_SEP << e.userName() << CSV_SEP << e.password() << CSV_SEP << e.notes() << CSV_NL;
+        out << e.name() << CSV_SEP << e.category() << CSV_SEP << e.userName() << CSV_SEP << e.password() << CSV_SEP << e.notes().replace("\n", "<br />") << CSV_NL;
     }
 
     out.flush();
@@ -148,11 +151,24 @@ void EntryListModel::updateEntryAt(int index, QString name, QString category, QS
     emit changed();
 }
 
-void EntryListModel::importKeePassXml(){
-    KeePassXmlStreamReader reader;
+void EntryListModel::appendEntries(const QList<Entry> entries){
     beginResetModel();
-    m_entries.append(reader.openFileForImport());
+    m_entries.append(entries);
     qSort(m_entries.begin(), m_entries.end(), entryCompare);
     endResetModel();
     emit changed();
 }
+
+QStringList EntryListModel::getItemNames() const {
+    QStringList items;
+
+    for(int i = 0; i < m_entries.size(); i++){
+        QString category = m_entries[i].category();
+
+        if(! items.contains(category)){
+            items.append(category);
+        }
+    }
+
+    return items;
+}
